@@ -35,5 +35,6 @@ return [
         'width' => 540,
         'height' => 500,
         'html' => '<blockquote class="imgur-embed-pub" lang="en" data-id="X6rkCc5"><a href="https://imgur.com/X6rkCc5">Picture of a Mountain Gorilla right before he punched the photographer</a></blockquote><script async src="//s.imgur.com/min/embed.js" charset="utf-8"></script>'
-    ]
+    ],
+    'allLinkedData' => []
 ];
