@@ -27,5 +27,6 @@ return [
     'title' => null,
     'url' => 'https://www.soundhelix.com/examples/mp3/SoundHelix-Song-1.mp3',
     'linkedData' => [],
-    'oEmbed' => []
+    'oEmbed' => [],
+    'allLinkedData' => []
 ];
