@@ -42,5 +42,6 @@ return [
         'thumbnail_url' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
         'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
         'url' => 'http://youtu.be/eiHXASgRTcA'
-    ]
+    ],
+    'allLinkedData' => []
 ];
